pub struct BindingEntry {
pub name: String,
pub kind: BindingKind,
pub physical_name: String,
pub declared: Option<Binding>,
pub resolved: Option<ResolvedBinding>,
}Expand description
One entry in an EnvBindings table.
Fields
name: Stringkind: BindingKindphysical_name: Stringdeclared: Option<Binding>The declared dependencies binding, when this entry came from one.
resolved: Option<ResolvedBinding>The cached resolution for this entry, when one is available.