pub fn semantic_eq(kind: ResourceKind, a: &Value, b: &Value) -> boolExpand description
Are two documents semantically equal for this kind (after normalization)?
pub fn semantic_eq(kind: ResourceKind, a: &Value, b: &Value) -> boolAre two documents semantically equal for this kind (after normalization)?