ProviderMeta

Struct ProviderMeta 

pub struct ProviderMeta {
    pub provider: Provider,
    pub label: &'static str,
    pub stable: &'static str,
    pub preview: Option<&'static str>,
    pub audience: &'static str,
    pub spec_path: Option<&'static str>,
    pub preview_spec_path: Option<&'static str>,
    pub route_versioned: bool,
    pub arm: Option<ArmRegistration>,
    pub hold: Option<Hold>,
}

Fields

provider: Providerlabel: &'static str

Human label for rigg dev api-check.

stable: &'static strpreview: Option<&'static str>audience: &'static str

Token audience (scope base, without /.default).

spec_path: Option<&'static str>

Folder in Azure/azure-rest-api-specs whose entries are version folders (None for route-versioned APIs and APIs not in that repository).

preview_spec_path: Option<&'static str>

Preview folder in the specs repository, when rigg uses a preview.

route_versioned: boolarm: Option<ArmRegistration>

ARM registration coordinates for this provider’s resource types (None for data-plane/route-versioned APIs, and for the ARM registration API itself).

hold: Option<Hold>

Set when stable is deliberately held below the newest spec-repo version.